import React, { useEffect, useRef, useMemo, useState } from 'react';
import { Layout, Spin } from 'antd';
import { Helmet } from "react-helmet";
import { useModel } from '@/store';
import useRoute from '@/routes/useRoute';
import RequireLogin from './components/RequireLogin';
import SiderBar from './components/SiderBar';
import Header from './components/Header';
import Container from './components/Container';
import useReady from './useReady';

import './style.less';

export default (props) => {
  const { config } = useModel('system');
  const { user, getCurrent } = useModel('user');
  // const isReady = useReady(user)
  // const isReady = true

  const currentRoute = useRoute();
  const titleTemplate = `%s - ${config.appName}`
  const pageTitle = currentRoute && currentRoute.meta ? currentRoute.meta.title : undefined;

  useEffect(() => {
    if (!user) {
      getCurrent()
    }
  }, []);

  return (
    <Spin spinning={!user} size="large">
      <Helmet titleTemplate={titleTemplate} defaultTitle={config.appName}>
        <title>{pageTitle}</title>
      </Helmet>
      <RequireLogin>
        <div className='main-layout'>
          <Header />
          <Layout>
            <SiderBar />
            <Container />
          </Layout>
        </div>
      </RequireLogin>
    </Spin>
  );
}
