import React, { useEffect } from 'react';
import { Helmet } from "react-helmet";
import { useModel } from '@/store';
import LoginForm from './LoginForm';
import LoginEffect from './Effect';
import './style.less';

const year = new Date().getFullYear();

export default (props) => {
  const { config } = useModel('system');

  const baseUrl = import.meta.env.BASE_URL;
  const title = `欢迎使用${config.appName}`;
  const copyright = `${config.company} @ ${year}`;

  useEffect(() => {
    const oScript = document.createElement("script");
    oScript.type = "text\/javascript";
    oScript.onload = () => {
      particlesJS.load('particles-js', `${baseUrl}particles/particles.json`, function() {
        console.log('callback - particles.js config loaded');
      });
    }
    document.querySelector('head').appendChild(oScript);
    oScript.src = `${baseUrl}particles/particles.min.js`;

    return () => {
      document.querySelector('head').removeChild(oScript);
    }
  }, [])

  return (
    <div className='login-page'>
      <Helmet>
        <title>{config.appName}</title>
      </Helmet>
      <div id="particles-js"></div>
      <div className="login-page-container">
        <div className="login-card">
          <div className="login-card-left">
            <div className="login-form-box">
              <div className="login-form">
                <h2>登录系统</h2>
                <div className="login-subtitle">{title}</div>
                <LoginForm />
              </div>
            </div>
            <div className="login-copyright">
              {copyright}
            </div>
          </div>
          <div className="login-card-right">
            <LoginEffect />
          </div>
        </div>
      </div>
    </div>
  )
}
